@@ -9,6 +9,7 @@ pub(crate) enum Setting<'src> {
   IgnoreComments(bool),
   PositionalArguments(bool),
   Shell(Shell<'src>),
+  Tempdir(String),
   WindowsPowerShell(bool),
   WindowsShell(Shell<'src>),
 }
@@ -24,6 +25,9 @@ impl<'src> Display for Setting<'src> {
       | Setting::PositionalArguments(value)
       | Setting::WindowsPowerShell(value) => write!(f, "{}", value),
       Setting::Shell(shell) | Setting::WindowsShell(shell) => write!(f, "{}", shell),
+      Setting::Tempdir(tempdir) => {
+        write!(f, "{:?}", tempdir)
+      }
     }
   }
 }
