@@ -60,10 +60,12 @@ mod json;
 mod line_prefixes;
 mod misc;
 mod multibyte_char;
+mod no_cd;
 mod no_exit_message;
 mod os_attributes;
 mod parser;
 mod positional_arguments;
+mod private;
 mod quiet;
 mod quote;
 mod readme;
